from green.plugin import Green
from green.version import version
from green.cmdline import main

# So pyflakes will stop complaining about disuse...
Green
version
main
